summaryrefslogtreecommitdiffstats
path: root/src/kernel
diff options
context:
space:
mode:
authorMike Baiocchi <mbaiocch@us.ibm.com>2017-05-24 15:20:04 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-06-16 10:26:05 -0400
commit44d178b6d050d9491e35360d5f3867e23c8ee895 (patch)
tree42c0ef3536fdf919ec66a311099c0805cab4ba3a /src/kernel
parenta7f35811ff731c443d56cee934b6b53900c99c26 (diff)
downloadtalos-hostboot-44d178b6d050d9491e35360d5f3867e23c8ee895.tar.gz
talos-hostboot-44d178b6d050d9491e35360d5f3867e23c8ee895.zip
Use Scratch Reg 3 Bit 7 to allow Attribute Overrides in Secure Mode
Change-Id: Ic9b220dc3480c13e1b1ac1c69a0be148ab5ea977 RTC:163094 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/41114 Reviewed-by: Stephen M. Cprek <smcprek@us.ibm.com> Reviewed-by: Martin Gloff <mgloff@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Marshall J. Wilks <mjwilks@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/kernel')
-rw-r--r--src/kernel/bltohbdatamgr.C21
1 files changed, 19 insertions, 2 deletions
diff --git a/src/kernel/bltohbdatamgr.C b/src/kernel/bltohbdatamgr.C
index 1623cf485..95a21ab17 100644
--- a/src/kernel/bltohbdatamgr.C
+++ b/src/kernel/bltohbdatamgr.C
@@ -27,6 +27,7 @@
#include <kernel/console.H>
#include <assert.h>
#include <arch/memorymap.H>
+#include <bootloader/bootloaderif.H>
// Global and only BlToHbDataManager instance
BlToHbDataManager g_BlToHbDataManager;
@@ -57,7 +58,9 @@ void BlToHbDataManager::print() const
if(iv_data.version >= Bootloader::BLTOHB_SAB)
{
- printkd("-- secureAccessBit = 0x%X\n", iv_data.secureAccessBit);
+ printkd("-- secureSettings: SAB=%d, SecOvrd=%d, AllowAttrOvrd=%d\n",
+ iv_data.secureAccessBit, iv_data.securityOverride,
+ iv_data.allowAttrOverrides);
}
if(iv_dataValid)
{
@@ -124,10 +127,12 @@ void BlToHbDataManager::initValid (const Bootloader::BlToHbData& i_data)
iv_data.hbbHeaderSize = i_data.hbbHeaderSize;
printk("Version=%lX\n",i_data.version);
// Ensure Bootloader to HB structure has the SAB member
if(iv_data.version >= Bootloader::BLTOHB_SAB)
{
iv_data.secureAccessBit = i_data.secureAccessBit;
+ iv_data.securityOverride = i_data.securityOverride;
+ iv_data.allowAttrOverrides = i_data.allowAttrOverrides;
}
// Ensure Bootloader to HB structure has the MMIO members
@@ -247,6 +252,18 @@ const bool BlToHbDataManager::getSecureAccessBit() const
return iv_data.secureAccessBit;
}
+const bool BlToHbDataManager::getSecurityOverride() const
+{
+ validAssert();
+ return iv_data.securityOverride;
+}
+
+const bool BlToHbDataManager::getAllowAttrOverrides() const
+{
+ validAssert();
+ return iv_data.allowAttrOverrides;
+}
+
const size_t BlToHbDataManager::getPreservedSize() const
{
validAssert();
@@ -124,10 +127,12 @@ void BlToHbDataManager::initValid (const Bootloader::BlToHbData& i_data)
iv_data.hbbHeaderSize = i_data.hbbHeaderSize;
printk("Version=%lX\n",i_data.version);
- // Ensure Bootloader to HB structure has the SAB member
+ // Ensure Bootloader to HB structure has the Secure Settings
if(iv_data.version >= Bootloader::BLTOHB_SAB)
{
OpenPOWER on IntegriCloud